// MRUManager.h
// (c) 2003-2004 exeal

#ifndef _MRU_MANAGER_H_
#define _MRU_MANAGER_H_

#include <list>
#include "..\Manah\Menu.h"
using Manah::Windows::Controls::CMenu;


// CMRUManager class definition
/////////////////////////////////////////////////////////////////////////////

namespace Alpha {

///	ŋߎgt@C̊Ǘ
class CMRUManager {
	// RXgN^
public:
	CMRUManager(unsigned short cLimit, int nStartID, bool bOwnerDrawMenu = false);
	virtual ~CMRUManager();

	// \bh
protected:
	void			_ReconstructMenu();
public:
	void			Add(const wstring& strFilePath);
	void			Clear();
	unsigned short	GetCount() const;
	const wstring&	GetFilePathAt(unsigned short i) const throw(out_of_range);
	CMenu*			GetPopupMenu() const;
	void			Remove(unsigned short i) throw(out_of_range);
	void			SetLimit(unsigned short cLimit);

	// f[^o
private:
	int				m_nStartID;			// j[ ID ̐擪̒l
	list<wstring>	m_listFileNames;	// tpX̃Xg
	CMenu*			m_pPopupMenu;		// |bvAbvj[
	unsigned short	m_cLimit;			// ڐ̏ (4ȏ16ȉ)
	bool			m_bOwnerDraw;		// j[I[i[hEɂ邩
};

}

#endif /* _MRU_MANAGER_H_ */

/* [EOF] */